==> casper-node-1.3.1.crate: casper-node-1.3.1/src/reactor/participating/config.rs <==
use datasize::DataSize;
use serde::Deserialize;

use crate::{
    logging::LoggingConfig, types::NodeConfig, BlockProposerConfig, ConsensusConfig,
    ContractRuntimeConfig, DeployAcceptorConfig, EventStreamServerConfig, FetcherConfig,
    GossipConfig, LinearChainSyncConfig, RestServerConfig, RpcServerConfig, SmallNetworkConfig,
    StorageConfig,
};

/// Root configuration.
#[derive(DataSize, Debug, Default, Deserialize)]
// Disallow unknown fields to ensure config files and command-line overrides contain valid keys.
#[serde(deny_unknown_fields)]
pub struct Config {
    /// Node configuration.
    pub node: NodeConfig,
    /// Logging configuration.
    pub logging: LoggingConfig,
    /// Consensus configuration.
    pub consensus: ConsensusConfig,
    /// Network configuration.
    pub network: SmallNetworkConfig,
    /// Event stream API server configuration.
    pub event_stream_server: EventStreamServerConfig,
    /// REST API server configuration.
    pub rest_server: RestServerConfig,
    /// RPC API server configuration.
    pub rpc_server: RpcServerConfig,
    /// On-disk storage configuration.
    pub storage: StorageConfig,
    /// Gossip protocol configuration.
    pub gossip: GossipConfig,
    /// Fetcher configuration.
    pub fetcher: FetcherConfig,
    /// Contract runtime configuration.
    pub contract_runtime: ContractRuntimeConfig,
    /// Deploy acceptor configuration.
    pub deploy_acceptor: DeployAcceptorConfig,
    /// Linear chain sync configuration.
    pub linear_chain_sync: LinearChainSyncConfig,
    /// Block proposer configuration.
    #[serde(default)]
    pub block_proposer: BlockProposerConfig,
}

==> casper-node-1.4.4.crate: casper-node-1.4.4/src/reactor/participating/config.rs <==
use datasize::DataSize;
use serde::Deserialize;

use crate::{
    logging::LoggingConfig, types::NodeConfig, BlockProposerConfig, ConsensusConfig,
    ContractRuntimeConfig, DeployAcceptorConfig, EventStreamServerConfig, FetcherConfig,
    GossipConfig, LinearChainSyncConfig, RestServerConfig, RpcServerConfig, SmallNetworkConfig,
    StorageConfig,
};

/// Root configuration.
#[derive(DataSize, Debug, Default, Deserialize)]
// Disallow unknown fields to ensure config files and command-line overrides contain valid keys.
#[serde(deny_unknown_fields)]
pub(crate) struct Config {
    /// Node configuration.
    pub(crate) node: NodeConfig,
    /// Logging configuration.
    pub(crate) logging: LoggingConfig,
    /// Consensus configuration.
    pub(crate) consensus: ConsensusConfig,
    /// Network configuration.
    pub(crate) network: SmallNetworkConfig,
    /// Event stream API server configuration.
    pub(crate) event_stream_server: EventStreamServerConfig,
    /// REST API server configuration.
    pub(crate) rest_server: RestServerConfig,
    /// RPC API server configuration.
    pub(crate) rpc_server: RpcServerConfig,
    /// On-disk storage configuration.
    pub(crate) storage: StorageConfig,
    /// Gossip protocol configuration.
    pub(crate) gossip: GossipConfig,
    /// Fetcher configuration.
    pub(crate) fetcher: FetcherConfig,
    /// Contract runtime configuration.
    pub(crate) contract_runtime: ContractRuntimeConfig,
    /// Deploy acceptor configuration.
    pub(crate) deploy_acceptor: DeployAcceptorConfig,
    /// Linear chain sync configuration.
    pub(crate) linear_chain_sync: LinearChainSyncConfig,
    /// Block proposer configuration.
    #[serde(default)]
    pub(crate) block_proposer: BlockProposerConfig,
}
